# Generated by roxygen2: do not edit by hand

S3method(print,apifetch_api)
export(af_api)
export(af_auth_bearer)
export(af_auth_header)
export(af_auth_query)
export(af_auth_raw)
export(af_fetch)
export(af_fetch_all)
export(af_get_token)
export(af_list_tokens)
export(af_paginate_none)
export(af_paginate_offset)
export(af_remove_token)
export(af_store_token)
export(parse_queries)
