% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/tokens.R
\name{af_list_tokens}
\alias{af_list_tokens}
\title{List stored API tokens}
\usage{
af_list_tokens(service = "apifetch")
}
\arguments{
\item{service}{A namespace prefix grouping tokens for one API. Default
\code{"apifetch"}.}
}
\value{
A character vector of token names, empty if none are found.
}
\description{
Returns the names (without the \code{service} prefix) of all tokens stored for a
given \code{service} in environment variables.
}
\examples{
af_list_tokens(service = "BigDataPE")
}
